---
name: Something is not working
about: Create a report to help us improve
title: ''
labels: help wanted
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior (including sample data and code really help):
1. Starting with image '...'
2. Run function(s) '....'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Local environment (please complete the following information):**
 - OS: [e.g. Linux, macOS, Windows]
 - Environment [e.g. conda, virtualenv, pip, docker, etc.]
 - PlantCV Version [e.g. 3.6.0]

**Additional context**
Add any other context about the problem here.
